@@ -1,33 +1,36 @@
 # This file is part of python-markups module
 # License: 3-clause BSD, see LICENSE file
-# Copyright: (C) Dmitry Shachnev, 2012-2018
+# Copyright: (C) Dmitry Shachnev, 2012-2021
 
-import pkg_resources
+from typing import List, Optional, Type
+from markups.abstract import AbstractMarkup
 from markups.markdown import MarkdownMarkup
 from markups.restructuredtext import ReStructuredTextMarkup
 from markups.textile import TextileMarkup
 
-__version_tuple__ = (3, 0, 0)
+__version_tuple__ = (3, 1, 1)
 __version__ = '.'.join(map(str, __version_tuple__))
 
 builtin_markups = [MarkdownMarkup, ReStructuredTextMarkup, TextileMarkup]
 
 # Public API
 
-def get_all_markups():
+def get_all_markups() -> List[Type[AbstractMarkup]]:
 	"""
 	:returns: list of all markups (both standard and custom ones)
-	:rtype: list of markup classes
 	"""
-	entry_points = pkg_resources.iter_entry_points("pymarkups")
-	return [entry_point.load() for entry_point in entry_points]
+	try:
+		from importlib.metadata import entry_points
+	except ImportError:  # backport for older Python versions
+		from importlib_metadata import entry_points
+	entrypoints = entry_points()["pymarkups"]
+	return [entry_point.load() for entry_point in entrypoints]
 
-def get_available_markups():
+def get_available_markups() -> List[Type[AbstractMarkup]]:
 	"""
 	:returns: list of all available markups (markups whose
 	          :meth:`~markups.abstract.AbstractMarkup.available`
 	          method returns True)
-	:rtype: list of markup classes
 	"""
 	available_markups = []
 	for markup in get_all_markups():
@@ -35,17 +38,15 @@ def get_available_markups():
 			available_markups.append(markup)
 	return available_markups
 
-def get_markup_for_file_name(filename, return_class=False):
+def get_markup_for_file_name(filename: str, return_class: bool = False):
 	"""
 	:param filename: name of the file
-	:type filename: str
 	:param return_class: if true, this function will return
 	                     a class rather than an instance
-	:type return_class: bool
 
 	:returns: a markup with
 	          :attr:`~markups.abstract.AbstractMarkup.file_extensions`
-                  attribute containing extension of `filename`, if found,
+	          attribute containing extension of `filename`, if found,
 	          otherwise ``None``
 
 	>>> import markups
@@ -65,12 +66,11 @@ def get_markup_for_file_name(filename, return_class=False):
 	if markup_class and markup_class.available():
 		return markup_class(filename=filename)
 
-def find_markup_class_by_name(name):
+def find_markup_class_by_name(name: str) -> Optional[Type[AbstractMarkup]]:
 	"""
 	:returns: a markup with
 	          :attr:`~markups.abstract.AbstractMarkup.name`
 	          attribute matching `name`, if found, otherwise ``None``
-	:rtype: class
 
 	>>> import markups
 	>>> markups.find_markup_class_by_name('textile')
@@ -79,3 +79,4 @@ def find_markup_class_by_name(name):
 	for markup in get_all_markups():
 		if markup.name.lower() == name.lower():
 			return markup
+	return None
