@@ -2,10 +2,9 @@
 
 # This file is part of python-markups module
 # License: 3-clause BSD, see LICENSE file
-# Copyright: (C) Dmitry Shachnev, 2013-2017
-
-from __future__ import absolute_import
+# Copyright: (C) Dmitry Shachnev, 2013-2021
 
+import importlib
 import markups.common as common
 from markups.abstract import AbstractMarkup, ConvertedMarkup
 
@@ -26,7 +25,7 @@ class TextileMarkup(AbstractMarkup):
 	@staticmethod
 	def available():
 		try:
-			import textile
+			importlib.import_module('textile')
 		except ImportError:
 			return False
 		return True
